@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__author__ = """Hans Christoph Schabert"""
+__author__ = """Christoph Schabert"""
 __email__ = 'christoph@schabert.me'
-__version__ = '0.1.5'
+__version__ = '0.1.10'
 
 
 class Event(object):
